@@ -706,6 +706,16 @@ Get all database contents.
  [1, [1, 2, 3], 2, {'key': 'val'}]
  >>> conn.close()
 
+Connection.getRemoveConflicts()
+===============================
+
+Get current default value of ``remove_conflicts`` keyword (the one which was set
+when connection was created, in `connect()`_).
+
+**Arguments**: ``getRemoveConflicts()``
+
+**Returns**: True or False
+
 .. _Connection.insert():
 
 .. _Connection.insertMany():
@@ -1069,6 +1079,26 @@ depend on DB engine).
  True
  >>> conn.close()
 
+CachedConnection
+~~~~~~~~~~~~~~~~
+
+This class wraps anything with `Connection`_-like interface and adds object caching.
+The caching algorithm is rather simple, it speeds up only read operations (by keeping
+copies of objects in memory).
+
+**Warning**: This class can work incorrectly if more than one connection to database is opened.
+For example, if the second connection changes something in database, the cache will not change
+and, therefore, read operation from the first connection will return the old value.
+
+**Arguments**: ``CachedConnection(conn, size_threshold=0)``
+
+``conn``:
+  Object with `Connection`_ interface.
+
+``size_threshold``:
+  How many objects the cache must keep in memory. If zero, all accessed objects are kept.
+  If non-zero, specifies the number of most recently accessed object kept.
+
 Client
 ~~~~~~
 
